/*
 * JScroll - the scrollable desktop pane for Java.
 * Copyright (C) 2003 Tom Tessier
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */

import org.jscroll.JScrollDesktopPane;

import javax.swing.*;

import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;


/**
 * This class provides a simple example of the scrollable desktop.
 *
 * To compile against scrollabledesktop.jar:
 *
 *  javac -classpath scrollabledesktop.jar Listing1.java
 *
 * To execute against scrollabledesktop.jar:
 *
 *  java -classpath .;scrollabledesktop.jar Listing1
 *
 * Note that if scrollabledesktop.jar is added to the global classpath
 *  via the CLASSPATH environment variable, the -classpath attribute
 *  is unnecessary
 *
 */
public class Listing1 {
    /**
     * Creates a new Listing1 object.
     */
    public Listing1() {
        // prepare the JFrame
        JFrame f = new JFrame("Scrollable Desktop Example");
        f.setSize(300, 300);
        f.addWindowListener(new WindowAdapter() {
                public void windowClosing(WindowEvent e) {
                    System.exit(0);
                }
            });

        // prepare the menuBar
        JMenuBar menuBar = new JMenuBar();
        f.setJMenuBar(menuBar);

        // create the scrollable desktop instance and add it to the JFrame
        JScrollDesktopPane scrollableDesktop = new JScrollDesktopPane(menuBar);

        // add the scrollable desktop to the JFrame
        f.getContentPane().add(scrollableDesktop);
        f.setVisible(true);

        // add internal frames to the scrollable desktop
        for (int i = 0; i < 3; i++) {
            JPanel frameContents = new JPanel();
            frameContents.add(new JLabel("Internal frame " + i +
                    " of JScrollDesktopPane"));
            scrollableDesktop.add(frameContents);
        }
    }

    /**
     * creates an instance of the listing
     *
     * @param arg the command line arguments
     */
    public static void main(String[] arg) {
        new Listing1();
    }
}
